===============================================
 :mod:`xoutil.tasking` -- Task oriented tools.
===============================================

.. automodule:: xoutil.tasking


.. autoclass:: retrier(max_tries=None, max_time=None, wait=DEFAULT_WAIT_INTERVAL, retry_only=None)
   :members: decorate

.. autofunction:: retry(fn, args=None, kwargs=None, *, max_tries=None, max_time=None, wait=DEFAULT_WAIT_INTERVAL, retry_only=None)

.. autoclass:: StandardWait(wait=DEFAULT_WAIT_INTERVAL)

.. autoclass:: BackoffWait(wait=DEFAULT_WAIT_INTERVAL)

.. autodata:: MIN_WAIT_INTERVAL

.. autodata:: DEFAULT_WAIT_INTERVAL
